@@ -227,6 +227,8 @@ INSTALLED_APPS = (
     'rooms',
     "django_cron",
     # 'elections',
+    "wiki",
+    "farnswiki",
     "notifications",
     'bootstrapform',
     'haystack',
@@ -238,8 +240,12 @@ INSTALLED_APPS = (
 CRON_CLASSES = [
     "managers.cron.ExpireRequestsCronJob",
     "workshift.cron.CollectBlownCronJob",
+    "workshift.cron.UpdateWeeklyStandings",
     ]
 
+WIKI_HOOKSET = "farnswiki.hooks.ProjectWikiHookset"
+WIKI_PARSE = "farnswiki.hooks.parse"
+
 AUTHENTICATION_BACKENDS = (
     'django.contrib.auth.backends.ModelBackend',
 )
